==> search_by_page-6.x-1.2.tar.gz: search_by_page/search_by_page.api.php <==
<?php
// $Id: search_by_page.api.php,v 1.1.2.1 2009/08/07 22:55:41 jhodgdon Exp $

/**
 * @file
 *
 * Search by Page Sub-Module API
 *
 * The Search by Page module allows you to define sub-modules that
 * tell Search by Page what pages to add to the search index. You
 * supply a Drupal path to the page you want to index. The Search by
 * Page module builds the page during Search indexing, and adds page
 * content to the core Drupal Search index.
 *
 * There are four hooks a sub-module can implement. The first three
 * are required, and the fourth is optional but recommended.
 *
 * There are also some helper functions defined in
 * search_by_page.module that may be useful (see documentation
 * there). These are: 
 * search_by_page_force_reindex(),
 * search_by_page_force_remove(), 
 * search_by_page_rebuild_paths(),
 * search_by_page_path_parts(), 
 * search_by_page_unique_rewrite()
 *
 */

/**
 * Return a list of pages to be indexed. 
 *
 * This hook is invoked whenever Search is building/adding to its
 * index (usually during a cron run). 
 *
 * @return
 *    Associative array of path items. 
 *    The array keys are the paths to be indexed. Each value is an array, 
 *    with the following components:
 *      'id':   ID number (unsigned integer) for module to reference this path.
 *         This is passed into the module's hook_sbp_details() implementation 
 *         when Search by Pages needs information about the page.
 *
 * @see hook_sbp_details()
 */
function hook_sbp_paths() {
  return array(
    'my/drupal/path' => array( 
      'id' => 1234
    ),
  );
}

/**
 * Return details about an indexed path.
 *
 * This hook is invoked after a search, to get full information about
 * what to display.
 *
 * This hook is also invoked during search indexing to get the page title
 * which is added to the indexed text. In this case, $keys will be null, and
 * the module can also return rendered content to be indexed, if desired.
 *
 * @param $id
 *    The ID corresponding to the path. This is the ID number you 
 *    returned in hook_sbp_paths(), for this path.
 * @param $keys
 *    The keywords being searched for (useful in extracting a snippet). NULL
 *    indicates this call is for search indexing.
 * @return
 *    If for some reason this path should not be
 *    displayed or indexed, return NULL or zero.
 *    If $keys is null, return an associative array for search
 *    indexing, with component 'title' (the page title) and optional
 *    component 'content' (an override of the page content, to avoid
 *    standard Drupal rendering).
 *    If keywords are not null, return an associative array of fields
 *    suitable for display on search results screen for this path. See
 *    the Drupal documentation for hook_search() for a list of what
 *    the fields are. The 'title' component must be given.  The 'link'
 *    component should be omitted (it is handled by the main
 *    search_by_page module).  The search_excerpt() function may be
 *    useful in extracting a 'snippet'.
 *
 * @see hook_sbp_paths()
 */
function hook_sbp_details( $id, $keys = NULL ) {
  $node = my_module_get_node( $id );
  return array( 
    'type' => check_plain( node_get_types( 'name', $node )),
    'title' => $node->title,
    'user' => theme( 'username', $node ),
    'date' => $node->changed,
    'extra' => $node->extra,
    'snippet' => search_excerpt( $keys, $node->body ),
  );
}

/**
 * Add conditions to the search query.
 *
 * This hook is required. It allows a module to add conditions
 * (usually related to access permissions) to the query that finds
 * the search results. These will be passed into do_search(), to limit
 * the search results.
 *
 * @return 
 *   Array with components:
 *   'join': Join expression to add to the search query, using "sp.modid"
 *     as the ID column to join on (i.e. the ID your module returned in
 *     hook_sbp_paths() ). All joins should be LEFT JOIN, because other
 *     modules will also have independent joins to do.
 *   'where': Where clause to add to the query, for rows where the join
 *     applies.
 *   'arguments': Array of arguments to be substituted in for %d, %s, etc.
 *     in the where clause.
 */
function hook_sbp_query_modify() {
  // This example gives access to every path defined by this module.
  return array(
    'join' => '',
    'where' => 1,
    'arguments' => array(),
  );
}

/**
 * Add settings to the Search by Page settings screen.
 * 
 * The returned form array is passed through system_settings_form(),
 * and displayed as a component of the page at URL
 * admin/settings/search_by_page.
 *
 * This hook is optional. If your module has no settings,
 * you need not implement this hook. Your module can also define its
 * own settings page with path 'admin/settings/search_by_page/whatever'
 * of type MENU_LOCAL_TASK, to add a tab to the settings page.
 *
 * Note that the database of paths is updated after the settings are 
 * submitted, so you do not need to do anything special to make this happen
 * if you use this hook. If you use your own settings page, you may want
 * to make use of these three functions:
 *   search_by_page_force_reindex()
 *   search_by_page_force_remove()
 *   search_by_page_rebuild_paths()
 * 
 * @return
 *   Form API array that defines one or more fieldsets to add to the 
 *   Search by Page settings screen at admin/settings/search_by_page.
 *   If you want to use weights for your fieldsets, choose numbers between
 *   -98 and -1.
 */
function hook_sbp_settings() {
  $form = array();
  // add your settings form components here
  return $form;
}

==> search_by_page-6.x-1.3.tar.gz: search_by_page/search_by_page.api.php <==
<?php
// $Id: search_by_page.api.php,v 1.1.2.2 2009/08/25 17:25:02 jhodgdon Exp $

/**
 * @file
 * Search by Page sub-module hook API.
 *
 * The Search by Page module allows you to define sub-modules that
 * tell Search by Page what pages to add to the search index. You
 * supply a Drupal path to the page you want to index. The Search by
 * Page module builds the page during Search indexing, and adds page
 * content to the core Drupal Search index.
 *
 * There are four hooks a sub-module can implement. The first three
 * are required, and the fourth is optional but recommended.
 *
 * There are also some helper functions defined in
 * search_by_page.module that may be useful (see documentation
 * there). These are: 
 * search_by_page_force_reindex(),
 * search_by_page_force_remove(), 
 * search_by_page_rebuild_paths(),
 * search_by_page_path_parts(), 
 * search_by_page_unique_rewrite()
 *
 * @ingroup search_by_page
 */

/**
 * Return a list of pages to be indexed (required hook).
 *
 * This hook is invoked whenever Search is building/adding to its
 * index (usually during a cron run).
 *
 * @return
 *    Associative array of path items.
 *    The array keys are the paths to be indexed. Each value is an array,
 *    with the following components:
 *      - 'id':   ID number (unsigned integer) for module to reference this
 *        path. This is passed into the module's hook_sbp_details()
          implementation when Search by Pages needs information about the page.
 *
 * @see hook_sbp_details()
 */
function hook_sbp_paths() {
  return array(
    'my/drupal/path' => array( 
      'id' => 1234
    ),
  );
}

/**
 * Return details about an indexed path (required hook).
 *
 * This hook is invoked after a search, to get full information about
 * what to display.
 *
 * This hook is also invoked during search indexing to get the page title
 * which is added to the indexed text. In this case, $keys will be null, and
 * the module can also return rendered content to be indexed, if desired.
 *
 * @param $id
 *    The ID corresponding to the path. This is the ID number you 
 *    returned in hook_sbp_paths(), for this path.
 * @param $keys
 *    The keywords being searched for (useful in extracting a snippet). NULL
 *    indicates this call is for search indexing.
 * @return
 *    - If for some reason this path should not be displayed or indexed,
 *      return NULL or zero.
 *    - If $keys is null, return an associative array for search
 *      indexing, with component 'title' (the page title) and optional
 *      component 'content' (an override of the page content, to avoid
 *      standard Drupal rendering).
 *    - If keywords are not null, return an associative array of fields
 *      suitable for display on search results screen for this path. See
 *      the Drupal documentation for hook_search() for a list of what
 *      the fields are. The 'title' component must be given.  The 'link'
 *      component should be omitted (it is handled by the main
 *      search_by_page module).  The search_excerpt() function may be
 *      useful in extracting a 'snippet'.
 *
 * @see hook_sbp_paths()
 */
function hook_sbp_details( $id, $keys = NULL ) {
  $node = my_module_get_node( $id );
  return array( 
    'type' => check_plain( node_get_types( 'name', $node )),
    'title' => $node->title,
    'user' => theme( 'username', $node ),
    'date' => $node->changed,
    'extra' => $node->extra,
    'snippet' => search_excerpt( $keys, $node->body ),
  );
}

/**
 * Add conditions to the search query (required hook).
 *
 * This hook allows a module to add conditions (usually related to
 * access permissions) to the query that finds the search
 * results. These will be passed into do_search(), to limit the search
 * results.
 *
 * @return 
 *   Array with components:
 *   - 'join': Join expression to add to the search query, using "sp.modid"
 *     as the ID column to join on (i.e. the ID your module returned in
 *     hook_sbp_paths() ). All joins should be LEFT JOIN, because other
 *     modules will also have independent joins to do.
 *   - 'where': Where clause to add to the query, for rows where the join
 *     applies.
 *   - 'arguments': Array of arguments to be substituted in for %d, %s, etc.
 *     in the where clause.
 */
function hook_sbp_query_modify() {
  // This example gives access to every path defined by this module.
  return array(
    'join' => '',
    'where' => 1,
    'arguments' => array(),
  );
}

/**
 * Add settings to the Search by Page settings screen (optional hook).
 * 
 * The returned form array is passed through system_settings_form(),
 * and displayed as a component of the page at URL
 * admin/settings/search_by_page.
 *
 * If your module has no settings, you need not implement this
 * hook. If your module has many settings, you can also define your own
 * settings page with path 'admin/settings/search_by_page/whatever' of
 * type MENU_LOCAL_TASK, to add a tab to the settings page.
 *
 * Note that the database of paths is updated after the settings are 
 * submitted, so you do not need to do anything special to make this happen
 * if you use this hook. If you use your own settings page, you may want
 * to make use of these three functions:
 *   search_by_page_force_reindex()
 *   search_by_page_force_remove()
 *   search_by_page_rebuild_paths()
 * 
 * @return
 *   Form API array that defines one or more fieldsets to add to the 
 *   Search by Page settings screen at admin/settings/search_by_page.
 *   If you want to use weights for your fieldsets, choose numbers between
 *   -98 and -1.
 */
function hook_sbp_settings() {
  $form = array();
  // add your settings form components here
  return $form;
}
